@@ -75,7 +75,11 @@ class CredentialMixin(BaseCredentialMixin):
 
         return auth_info["is_admin"]
 
-    def get_credential(self, request, model=None):
+    def check_mongo_credential(self):
+        mongo_credential = getattr(settings, 'MONGODANTIC_CREDENTIAL', False)
+        return mongo_credential
+
+    def get_credential(self, request, model=None, mongodantic=False):
         """[summary]
 
         Arguments:
@@ -94,12 +98,19 @@ class CredentialMixin(BaseCredentialMixin):
             model = self.get_credential_model()
 
         cred_id = request.GET.get("credential_id")
+        mongodantic = mongodantic or self.check_mongo_credential()
+        if not mongodantic:
+            params = {
+                'id': cred_id,
+            }
 
-        params = {
-            'id': cred_id,
-        }
+            credential = model.objects.filter(**params).first()
+        else:
+            params = {
+                '_id': cred_id,
+            }
 
-        credential = model.objects.filter(**params).first()
+            credential = model.querybuilder.find_one(**params)
         if not credential:
             raise PermissionDenied(
                 {"status": "error", "message": "Credential does not exist."}
